@@ -13,6 +13,7 @@ these different cases.
 
 from __future__ import absolute_import
 
+from warnings import warn
 import uuid
 
 from .protocol import serialize_json
@@ -23,7 +24,17 @@ from .templates import (
 )
 from .util.string import encode_utf8
 
-def components(plot_object, resources):
+from .plot_object import PlotObject
+from collections import Sequence
+from six import string_types
+
+def _wrap_in_function(code):
+    # Indent and wrap Bokeh function def around
+    code = "\n".join([ "    " + line for line in code.split("\n") ])
+    return 'Bokeh.$(function() {\n%s\n});' % code
+
+
+def components(plot_objects, resources=None):
     ''' Return HTML components to embed a Bokeh plot.
 
     The data for the plot is stored directly in the returned HTML.
@@ -32,30 +43,92 @@ def components(plot_object, resources):
               are **already loaded**.
 
     Args:
-        plot_object (PlotObject) : Bokeh object to render
-            typically a Plot or PlotContext
-        resources (Resources, optional) : BokehJS resources config
+        plot_objects (PlotObject|list|dict|tuple) :
+        The |components| function takes either a single PlotObject, a list/tuple of
+        PlotObjects, or a dictionary of keys and PlotObjects. Each returns
+        a corresponding data structure of script and div pairs.
+
+        The following illustrates how different input types correlate to outputs:
+
+            components(plot)
+            #=> (script, plot_div)
+
+            components((plot_1, plot_2))
+            #=> (script, (plot_1_div, plot_2_div))
+
+            components({"Plot 1": plot_1, "Plot 2": plot_2})
+            #=> (script, {"Plot 1": plot_1_div, "Plot 2": plot_2_div})
+
+        An example can be found in examples/embed/embed_multiple.py
+
+        resources : Deprecated argument
 
     Returns:
-        (script, div) : UTF-8 encoded
-
+        (script, div[s]): UTF-8 encoded
     '''
-    ref = plot_object.ref
-    elementid = str(uuid.uuid4())
+    from .document import Document
+    if isinstance(plot_objects, (PlotObject, Document)):
+        plot_objects = [plot_objects]
+    if resources is not None:
+        warn('Because the ``resources`` argument is no longer needed, '
+             'it is deprecated and will be removed in'
+             'a future version.', DeprecationWarning, stacklevel=2)
+    all_models = []
+    plots = []
+    if isinstance(plot_objects, Sequence) and all(isinstance(x, (PlotObject, Document)) for x in plot_objects):
+        divs = []
+        for idx, plot_object in enumerate(plot_objects):
+            elementid = str(uuid.uuid4())
+            _append_plot(all_models, plots, plot_object, elementid)
+            divs = _append_div(elementid, divs)
+        if len(divs) == 1:
+            divs = divs[0]
+        else:
+            divs = tuple(divs)
+        return _component_pair(all_models, plots, divs)
+    elif isinstance(plot_objects, dict) and \
+         all(isinstance(x, string_types) for x in plot_objects.keys()) and \
+         all(isinstance(x, (PlotObject, Document)) for x in plot_objects.values()):
+        divs = {}
+        for key in plot_objects.keys():
+            elementid = str(uuid.uuid4())
+            _append_plot(all_models, plots, plot_objects[key], elementid)
+            divs = _append_div(elementid, divs, key)
+        return _component_pair(all_models, plots, divs)
+    else:
+        raise ValueError('Input must be a PlotObject, a Sequence of PlotObjects, or a mapping of string to PlotObjects')
 
+def _component_pair(all_models, plots, divs):
     js = PLOT_JS.render(
-        elementid = elementid,
-        modelid = ref["id"],
-        modeltype = ref["type"],
-        all_models = serialize_json(plot_object.dump()),
+        all_models = serialize_json(all_models),
+        plots = plots
     )
     script = PLOT_SCRIPT.render(
-        plot_js = resources.js_wrapper(js),
+        plot_js = _wrap_in_function(js),
     )
-    div = PLOT_DIV.render(elementid=elementid)
+    return encode_utf8(script), divs
 
-    return encode_utf8(script), encode_utf8(div)
+def _append_plot(all_models, plots, plot_object, elementid):
+    ref = plot_object.ref
+    all_models.extend(plot_object.dump())
+    plots.append({
+        'modelid': ref["id"],
+        'elementid': '#' + elementid,
+        'modeltype': ref["type"]
+    })
 
+def _append_div(elementid, divs=None, key=None):
+    div = PLOT_DIV.render(
+        elementid = elementid
+    )
+    if isinstance(divs, list):
+        divs.append(encode_utf8(div))
+        return divs
+    elif isinstance(divs, dict):
+        divs[key] = encode_utf8(div)
+        return divs
+    else:
+        return encode_utf8(div)
 
 def notebook_div(plot_object):
     ''' Return HTML for a div that will display a Bokeh plot in an
@@ -70,22 +143,26 @@ def notebook_div(plot_object):
     Returns:
         div : UTF-8 encoded HTML text
 
-    .. note:: Assumes ``bokeh.load_notebook()`` or the equivalent has
-              already been executed.
+    .. note::
+        Assumes ``bokeh.load_notebook()`` or the equivalent has already
+        been executed.
 
     '''
     ref = plot_object.ref
-    resources = Resources()
     elementid = str(uuid.uuid4())
 
+    plots = [{
+        'modelid': ref["id"],
+        'elementid': '#' + elementid,
+        'modeltype': ref["type"]
+    }]
+
     js = PLOT_JS.render(
-        elementid = elementid,
-        modelid = ref["id"],
-        modeltype = ref["type"],
         all_models = serialize_json(plot_object.dump()),
+        plots = plots
     )
     script = PLOT_SCRIPT.render(
-        plot_js = resources.js_wrapper(js),
+        plot_js = _wrap_in_function(js),
     )
     div = PLOT_DIV.render(elementid=elementid)
     html = NOTEBOOK_DIV.render(
@@ -95,7 +172,7 @@ def notebook_div(plot_object):
     return encode_utf8(html)
 
 
-def file_html(plot_object, resources, title, template=FILE):
+def file_html(plot_object, resources, title, template=FILE, template_variables=None):
     ''' Return an HTML document that embeds a Bokeh plot.
 
     The data for the plot is stored directly in the returned HTML.
@@ -108,24 +185,36 @@ def file_html(plot_object, resources, title, template=FILE):
         template (Template, optional) : HTML document template (default: FILE)
             A Jinja2 Template, see bokeh.templates.FILE for the required
             template parameters
+        template_variables (dict, optional) : variables to be used in the Jinja2
+            template. If used, the following variable names will be overwritten:
+            title, plot_resources, plot_script, plot_div
 
     Returns:
         html : standalone HTML document with embedded plot
 
     '''
+    from .document import Document
+    if not isinstance(plot_object, (PlotObject, Document)):
+        raise ValueError('plot_object must be a single PlotObject')
+
     plot_resources = RESOURCES.render(
         js_raw = resources.js_raw,
         css_raw = resources.css_raw,
         js_files = resources.js_files,
         css_files = resources.css_files,
     )
-    script, div = components(plot_object, resources)
-    html = template.render(
-        title = title,
-        plot_resources = plot_resources,
-        plot_script = script,
-        plot_div = div,
+    script, div = components(plot_object)
+    template_variables_full = \
+        template_variables.copy() if template_variables is not None else {}
+    template_variables_full.update(
+        {
+            'title': title,
+            'plot_resources': plot_resources,
+            'plot_script': script,
+            'plot_div': div,
+        }
     )
+    html = template.render(template_variables_full)
     return encode_utf8(html)
 
 
@@ -183,7 +272,7 @@ def autoload_server(plot_object, session, public=False):
 
     Args:
         plot_object (PlotObject) :
-        session (session) :
+        session (Session) :
 
     Returns:
         tag :
