@@ -5,7 +5,7 @@ import numpy as np
 import pandas as pd
 from six.moves import cStringIO as StringIO
 
-from bokeh.plotting import *
+from bokeh.plotting import figure, show, output_file
 
 antibiotics = """
 bacteria,                        penicillin, streptomycin, neomycin, gram
