@@ -14,10 +14,11 @@ table = d.aapl
 source = line_downsample.source()
 source.from_blaze(table, local=True)
 
-p = figure(x_axis_type = "datetime")
+TOOLS="pan,wheel_zoom,box_zoom,reset,previewsave",
+
+p = figure(x_axis_type = "datetime", tools=TOOLS)
 p.line('date', 'close',
        color='#A6CEE3',
-       tools="pan,wheel_zoom,box_zoom,reset,previewsave",
        source=source,
        legend='AAPL')
 show(p)
